[Pkg-owncloud-commits] [owncloud-client] 15/70: Set network timeout to 300 sec

Sandro Knauß hefee-guest at moszumanska.debian.org
Sat May 17 20:01:25 UTC 2014


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit 6c44f536452e3748457fe9f4ef6b3f33ab0ad123
Author: Markus Goetz <markus at woboq.com>
Date:   Fri May 2 15:35:40 2014 +0200

    Set network timeout to 300 sec
    
    As per previously used values (see source and changelog)
---
 csync/src/csync_owncloud.c        | 1 +
 src/mirall/owncloudpropagator.cpp | 2 +-
 2 files changed, 2 insertions(+), 1 deletion(-)

diff --git a/csync/src/csync_owncloud.c b/csync/src/csync_owncloud.c
index 433271d..bf10baa 100644
--- a/csync/src/csync_owncloud.c
+++ b/csync/src/csync_owncloud.c
@@ -510,6 +510,7 @@ static int dav_connect(const char *base_url) {
 
     if (dav_session.read_timeout != 0) {
         ne_set_read_timeout(dav_session.ctx, dav_session.read_timeout);
+        DEBUG_WEBDAV("Timeout set to %u seconds", dav_session.read_timeout );
     }
 
     snprintf( uaBuf, sizeof(uaBuf), "Mozilla/5.0 (%s) csyncoC/%s",
diff --git a/src/mirall/owncloudpropagator.cpp b/src/mirall/owncloudpropagator.cpp
index 45f57af..c35fc6f 100644
--- a/src/mirall/owncloudpropagator.cpp
+++ b/src/mirall/owncloudpropagator.cpp
@@ -343,7 +343,7 @@ int OwncloudPropagator::httpTimeout()
     if (!timeout) {
         timeout = qgetenv("OWNCLOUD_TIMEOUT").toUInt();
         if (timeout == 0) {
-            timeout = 30; // default to 30 secs
+            timeout = 300; // default to 300 secs
         }
     }
     return timeout;

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list